#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-canon-lbp351-352-lips"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "Canon LBP351-352 LIPS" "Canon LBP6700 LIPS" "Canon LBP6710 LIPS" "Canon LBP8630-8620-8610 LIPS" "Canon LBP8720-8710 LIPS" "Canon LBP8730 LIPS" "Canon LBP8900 LIPS" "Canon LBP9650C LIPS" "Canon LBP9660C LIPS" "Canon LBP9950C-9900C LIPS" "Canon iR-ADV 4025-4035 LIPS" "Canon iR-ADV 4045 LIPS" "Canon iR-ADV 4225-4235 LIPS" "Canon iR-ADV 4245 LIPS" "Canon iR-ADV 6055-6065 LIPS" "Canon iR-ADV 6075 LIPS" "Canon iR-ADV 6255-6265 LIPS" "Canon iR-ADV 6275 LIPS" "Canon iR-ADV 6555-6565 LIPS" "Canon iR-ADV 6575 LIPS" "Canon iR-ADV 8085-8095 LIPS" "Canon iR-ADV 8105 LIPS" "Canon iR-ADV 8205 LIPS" "Canon iR-ADV 8285-8295 LIPS" "Canon iR-ADV 8505 LIPS" "Canon iR-ADV 8585-8595 LIPS" "Canon iR-ADV C2020-2030 LIPS" "Canon iR-ADV C2218 LIPS" "Canon iR-ADV C2220-2230 LIPS" "Canon iR-ADV C3320-3330 LIPS" "Canon iR-ADV C350 LIPS" "Canon iR-ADV C5030-5035 LIPS" "Canon iR-ADV C5045-5051 LIPS" "Canon iR-ADV C5235-5240 LIPS" "Canon iR-ADV C5250-5255 LIPS" "Canon iR-ADV C5535-5540 LIPS" "Canon iR-ADV C5550-5560 LIPS" "Canon iR-ADV C7055-7065 LIPS" "Canon iR-ADV C7260-7270 LIPS" "Canon iR-ADV C9065 LIPS" "Canon iR-ADV C9075 LIPS" "Canon iR-ADV C9270-9280 LIPS" "Canon iPR1110-1125-1135 LIPS" "Canon iPR C6010 LIPS" "Canon iPR C700-800 LIPS" "Canon iPR C7010VP LIPS" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
